RENAME_ATOMS = {
    "CTR": {"O": "O1", "OXT": "O2"},
    "NTR": {"H": "H1"},
    "ILE": {"CD1": "CD"},
    "CYS": {"HG": "HG1"},
    "SER": {"HG": "HG1"},
    "TYR": {"HH": "HH1"},
}

RESIDUE_REFSTATE = {
    "HSD": "HIS",
    "HSE": "HIS",
    "HSP": "HIS",
    "ARGN": "ARG",
    "ASPH": "ASP",
    "CYS1": "CYS",
    "CYS2": "CYS",
    "CYSH": "CYS",
    "GLUH": "GLU",
    "HISD": "HIS",
    "HISE": "HIS",
    "HISH": "HIS",
    "HISA": "HIS",
    "HISB": "HIS",
    "HISP": "HIS",
    "LYSH": "LYS",
    "LYSN": "LYS",
    "ISU": "CYS",
}

TITRATABLE_RESIDUES = (
    "LYS",
    "HIS",
    "ASP",
    "GLU",
    "SER",
    "THR",
    "CYS",
    "CTR",
    "NTR",
    "TYR",
)

PROTEIN_RESIDUES = (
    "ALA",
    "CYS",
    "ASP",
    "GLU",
    "PHE",
    "GLY",
    "HIS",
    "ILE",
    "LYS",
    "LEU",
    "MET",
    "ASN",
    "PRO",
    "GLN",
    "ARG",
    "SER",
    "THR",
    "VAL",
    "TRP",
    "TYR",
    "NTR",
    "CTR",
)
